@@ -11,6 +11,7 @@ from typing import Optional
 
 import oci
 import rich
+from bext import title
 from oci.exceptions import ServiceError
 
 from abst.config import default_creds_path, \
@@ -24,6 +25,7 @@ class Bastion:
     session_list = []
     session_desc = dict()
     custom_ssh_options: str = "-o ServerAliveInterval=20"
+    force_ssh_options: str = "-o StrictHostKeyChecking=no -o ServerAliveInterval=20 -o UserKnownHostsFile=/dev/null"
 
     def __init__(self, context_name=None, region=None):
         self.context_name = context_name
@@ -161,7 +163,7 @@ class Bastion:
         self.kill()
 
     @mark_on_exit
-    def create_forward_loop(self, shell: bool = False):
+    def create_forward_loop(self, shell: bool = False, force: bool = False):
 
         from abst.bastion_support.bastion_scheduler import BastionScheduler
         if BastionScheduler.stopped:
@@ -170,6 +172,8 @@ class Bastion:
         Bastion.shell = shell
         print(f"Loading Credentials for {self.get_print_name()}")
         creds = self.load_self_creds()
+        title(f'{creds["default-name"]}:{creds["local-port"]}')
+
         self.current_status = "creating bastion session"
 
         try:
@@ -200,7 +204,7 @@ class Bastion:
 
         ssh_tunnel_arg_str = self.run_ssh_tunnel_port_forward(bid, host, ip, port,
                                                               shell,
-                                                              creds.get("local-port", 22), ssh_pub_key_path)
+                                                              creds.get("local-port", 22), ssh_pub_key_path, force)
 
         while status := (sdata := self.get_bastion_state())[
                             "lifecycle_state"] == "ACTIVE" and \
@@ -228,10 +232,13 @@ class Bastion:
         exit_code = self.__run_ssh_tunnel_call(ssh_tunnel_args, shell, already_split=True)
         return ssh_tunnel_args, exit_code
 
-    def run_ssh_tunnel_port_forward(self, bid, host, ip, port, shell, local_port, ssh_pub_key_path):
+    def run_ssh_tunnel_port_forward(self, bid, host, ip, port, shell, local_port, ssh_pub_key_path, force=False):
         print(f"Bastion {self.get_print_name()} initialized")
         print(f"Initializing SSH Tunnel for {self.get_print_name()}")
-        ssh_tunnel_arg_str = f"ssh {self.custom_ssh_options} -N -L {local_port}:{ip}:{port} -p 22 {bid}@{host} -vvv -i {ssh_pub_key_path.strip('.pub')}"
+        additional_args = "" if not force else self.force_ssh_options
+
+        ssh_tunnel_arg_str = (f"ssh {self.custom_ssh_options} -N -L {local_port}:{ip}:{port} -p 22 {bid}@{host} "
+                              f"-vvv -i {ssh_pub_key_path.strip('.pub')} {additional_args}")
         self.__run_ssh_tunnel(ssh_tunnel_arg_str, shell)
         return ssh_tunnel_arg_str
 
@@ -257,6 +264,7 @@ class Bastion:
 
     def create_bastion_forward_port_session(self, creds):
         ssh_key_path = self.get_ssh_pub_key_path(creds)
+        cfg = Bastion.load_config()
 
         if "region" not in creds.keys():
             rich.print("Missing region, will use profile default")
@@ -266,12 +274,17 @@ class Bastion:
             rich.print("[red]SSH key has invalid path[/red]")
             exit(1)
 
+        ssh_pub_path = creds.get(ssh_key_path, cfg.get("ssh-pub-path", "No Public key supplied"))
+
+        if ssh_pub_path == "No Public key supplied":
+            raise Exception(ssh_pub_path)
+
         res = self.__create_bastion_session_port_forward(creds["bastion-id"],
                                                          creds["target-ip"],
                                                          f'{creds["default-name"]}-ctx-'
                                                          f'{self.get_print_name()}',
                                                          int(creds["target-port"]),
-                                                         ssh_key_path,
+                                                         ssh_pub_path,
                                                          int(creds["ttl"]), False, creds.get("region", None))
         try:
             trs = Bastion.parse_response(res)
@@ -280,10 +293,11 @@ class Bastion:
             logging.debug(f"Added session id of {self.context_name}")
         except:
             pass
-        return creds["host"], creds["target-ip"], creds["target-port"], creds["ssh-pub-path"], res
+        return creds["host"], creds["target-ip"], creds["target-port"], ssh_pub_path, res
 
     def create_bastion_ssh_session_managed(self, creds):
         ssh_key_path = self.get_ssh_pub_key_path(creds)
+        cfg = Bastion.load_config()
 
         if "region" not in creds.keys():
             rich.print("Missing region, will use profile default")
@@ -293,13 +307,18 @@ class Bastion:
             rich.print("[red]SSH key has invalid path[/red]")
             exit(1)
 
+        ssh_pub_path = creds.get(ssh_key_path, cfg.get("ssh-pub-path", "No Public key supplied"))
+
+        if ssh_pub_path == "No Public key supplied":
+            raise Exception(ssh_pub_path)
+
         try:
             res = self.__create_bastion_ssh_session_managed(creds["bastion-id"],
                                                             creds["resource-id"],
                                                             f'{creds["default-name"]}-ctx-'
                                                             f'{self.get_print_name()}',
                                                             creds["resource-os-username"],
-                                                            ssh_key_path,
+                                                            ssh_pub_path,
                                                             int(creds["ttl"]), False, creds.get("region", None)
                                                             )
             try:
@@ -373,6 +392,16 @@ class Bastion:
 
         if not default_conf_path.exists():
             cls.write_creds_json(default_conf_contents, default_conf_path)
+        else:
+            something_changed = False
+            data = Bastion.load_config()
+            for key, value in default_conf_contents.items():
+                if key not in data.keys():
+                    data[key] = value
+                    something_changed = True
+            if something_changed:
+                cls.write_creds_json(default_conf_contents, default_conf_path)
+                rich.print("[green]Updated .abst/config file[/green]")
 
     @classmethod
     def write_creds_json(cls, td: dict, path: Path):
