@@ -2,11 +2,11 @@ import rich
 from InquirerPy import inquirer
 
 from abst.config import default_config_keys
-from abst.oci_bastion import Bastion
+from abst.bastion_support.oci_bastion import Bastion
 
 
 def __upgrade(context_name, path):
-    creds_json_ro = Bastion.load_json(Bastion.get_creds_path(context_name))
+    creds_json_ro = Bastion.load_json(Bastion.get_creds_path_resolve(context_name))
     missing_keys = set(default_config_keys).difference(creds_json_ro.keys())
     res_json = dict(creds_json_ro)
     for key in missing_keys:
